# Please keep this package in sync with FC

# (tv) temp build fix:
BuildRequires: fakeroot

%bcond_with php

# Architectures on which golang works.
#% global golang_arches aarch64 % {arm} % {ix86} x86_64
# In theory the above, in practice golang is so often broken that
# I now disable it:
%global golang_arches NONE
 
# Architectures that we run the basic sanity-check test.
#
# The full test suite is done after the package has been built.  Here
# we only do a sanity check that kernel/qemu/libvirt/appliance is not
# broken.  To perform the full test suite, see instructions here:
# https://www.redhat.com/archives/libguestfs/2015-September/msg00078.html
#
# Currently the basic sanity check is *broken* on:
#
# arm:     times out when running the test
# aarch64: "MSI is not supported by interrupt controller" (RHBZ#1414081)
# ppc64:   qemu doesn't work with TCG (RHBZ#1614948)
# ppc64le: kernel doesn't boot on qemu (RHBZ#1435873)
# s390x:   qemu TCG cannot emulate enough to boot the kernel
#            (however KVM would work if it was available in Koji, so this
#            is not a bug)
%global test_arches x86_64

# Enable to run tests during check
# Default is enabled
#
%if %{defined libguestfs_runtests}
%global runtests %{libguestfs_runtests}
%else
%global runtests 0
%endif

# Note there needs to be some work done on this package.
# The problem is that the package using supermin to generate
# an image using the current cauldron build.  This can cause
# errors if the cauldron build is inconsistent, and this 
# creates a problem in that the same build will produce
# different images.
#
# What really should happen is that we should rewrite this
# so that the boot image is created when rpm is installed.

# Verify tarball signature with GPGv2.
%global verify_tarball_signature 1

# If there are patches which touch autotools files, set this to 1.
%global patches_touch_autotools %{nil}

# The source directory.
%global source_directory 1.44-stable

# Filter perl provides.
%{?perl_default_filter}

# Unbreak the linker.
%define _disable_ld_no_undefined 1
 
Summary:       Access and modify virtual machine disk images
Name:          libguestfs
Epoch:         1
Version:       1.44.0
Release:       %mkrel 2
License:       LGPLv2+
Group:         System/Libraries

# Source and patches.
URL:           http://libguestfs.org/
Source0:       http://libguestfs.org/download/%{source_directory}/%{name}-%{version}.tar.gz
%if 0%{verify_tarball_signature}
Source1:       http://libguestfs.org/download/%{source_directory}/%{name}-%{version}.tar.gz.sig
%endif

# Replacement README file.
Source4:       README-replacement.in

# Guestfish colour prompts.
Source5:       guestfish.sh

# Keyring used to verify tarball signature.
%if 0%{verify_tarball_signature}
Source7:       libguestfs.keyring
%endif

# Maintainer script which helps with handling patches.
Source8:       copy-patches.sh

# END OF FEDORA PATCHES
Patch20:        libguestfs-1.37.18-mga-lua.patch

%if 0%{patches_touch_autotools}
BuildRequires: autoconf, automake, libtool, gettext-devel
%endif

# Basic build requirements for the library and virt tools.
BuildRequires: gcc, gcc-c++
BuildRequires: make
BuildRequires: rpcgen
BuildRequires: libtirpc-devel
BuildRequires: supermin-devel >= 5.1.18
BuildRequires: hivex-devel >= 1.3.10
BuildRequires: ocaml-hivex-devel
BuildRequires: perl(Pod::Simple)
BuildRequires: perl(Pod::Man)
BuildRequires: po4a
BuildRequires: augeas-devel >= 1.7.0
BuildRequires: readline-devel
BuildRequires: genisoimage
BuildRequires: libxml2-devel
BuildRequires: glibc-static-devel
BuildRequires: createrepo_c
BuildRequires: glibc-static-devel
#BuildRequires: selinux-devel
BuildRequires: fuse, fuse-devel
BuildRequires: fuse-common
BuildRequires: pcre-devel
BuildRequires: file-devel
BuildRequires: libvirt-devel
BuildRequires: gperf
BuildRequires: flex
BuildRequires: bison
BuildRequires: db5-utils
BuildRequires: cpio
BuildRequires: libconfig-devel
BuildRequires: xz-devel
BuildRequires: zip
BuildRequires: unzip
BuildRequires: systemd-units
BuildRequires: netpbm
BuildRequires: icoutils
BuildRequires: libvirt-utils >= 5.3.0
BuildRequires: perl(Expect)
BuildRequires: libacl-devel
BuildRequires: libcap-devel
BuildRequires: pkgconfig(ldm-1.0)
BuildRequires: jansson-devel
BuildRequires: systemd-devel
BuildRequires: bash-completion
BuildRequires: iputils
BuildRequires: wget
BuildRequires: curl
BuildRequires: xz
BuildRequires: qemu-img
BuildRequires: perl(Win::Hivex)
BuildRequires: perl(Win::Hivex::Regedit)
BuildRequires: magic-devel
BuildRequires: locales-fr, locales-ja, locales-zh
BuildRequires: dnf

%if 0%{verify_tarball_signature}
BuildRequires: gnupg2
%endif

# For language bindings.
BuildRequires: ocaml
BuildRequires: ocaml-ocamldoc
BuildRequires: ocaml-findlib-devel
BuildRequires: ocaml-gettext-devel
BuildRequires: ocaml-ounit-devel
BuildRequires: lua5.3-devel
BuildRequires: perl-devel
BuildRequires: perl(Sys::Virt)
BuildRequires: perl(Test::More)
BuildRequires: perl(Test::Pod) >= 1.00
BuildRequires: perl(Test::Pod::Coverage) >= 1.00
BuildRequires: perl(Module::Build)
BuildRequires: perl(ExtUtils::CBuilder)
BuildRequires: perl(Locale::TextDomain)
BuildRequires: python3-devel
BuildRequires: python3-libvirt
BuildRequires: ruby-devel
BuildRequires: ruby-rake
# json is not pulled in automatically, see RHBZ#1325022
BuildRequires: rubygem(json)
BuildRequires: rubygem(rdoc)
BuildRequires: rubygem(test-unit)
BuildRequires: ruby-irb
%if %with php
BuildRequires: php-devel
BuildRequires: php-cli
%endif
BuildRequires: gobject-introspection-devel
BuildRequires: gjs
BuildRequires: vala
# (tv) for vapigen:
BuildRequires: pkgconfig(vapigen)
%ifarch %{golang_arches}
BuildRequires: golang
%endif

# Build requirements for the appliance.
#
# Get the initial list by doing:
#   for f in `cat appliance/packagelist`; do echo $f; done | sort -u
# However you have to edit the list down to packages which exist in
# current Fedora, since supermin ignores non-existent packages.
BuildRequires: acl
BuildRequires: attr
BuildRequires: augeas
BuildRequires: bash
BuildRequires: binutils
BuildRequires: btrfs-progs
BuildRequires: bzip2
BuildRequires: coreutils
BuildRequires: cpio
BuildRequires: cryptsetup
BuildRequires: curl
BuildRequires: debootstrap
BuildRequires: dhcp-client
BuildRequires: diffutils
BuildRequires: dosfstools
BuildRequires: e2fsprogs
BuildRequires: file
BuildRequires: findutils
BuildRequires: gawk
BuildRequires: gdisk
BuildRequires: genisoimage
BuildRequires: gfs2-utils
BuildRequires: grep
BuildRequires: gzip
BuildRequires: hfsplus-tools
BuildRequires: hivex
BuildRequires: iproute
BuildRequires: iputils
BuildRequires: jfsutils
BuildRequires: kernel
BuildRequires: kmod
BuildRequires: kpartx
BuildRequires: less
BuildRequires: libldm
BuildRequires: libxml2-utils
BuildRequires: lsof
BuildRequires: lsscsi
BuildRequires: lvm2
BuildRequires: lzop
BuildRequires: mdadm
BuildRequires: nilfs-utils
BuildRequires: ntfs-3g ntfsprogs ntfs-3g-system-compression
BuildRequires: openssh-clients
BuildRequires: parted
BuildRequires: pciutils
BuildRequires: pcre
BuildRequires: procps
BuildRequires: psmisc
BuildRequires: qemu-img
BuildRequires: reiserfs-utils
BuildRequires: rsync
BuildRequires: scrub
BuildRequires: sed
BuildRequires: sleuthkit
BuildRequires: squashfs-tools
BuildRequires: strace
%ifarch %{ix86} x86_64
BuildRequires: syslinux
%endif
BuildRequires: systemd
BuildRequires: tar
BuildRequires: udev
BuildRequires: util-linux
BuildRequires: vim-minimal
BuildRequires: which
BuildRequires: xfsprogs
BuildRequires: xz
BuildRequires: yajl
BuildRequires: zerofree
%ifnarch %{arm} aarch64 s390 s390x riscv64
# http://zfs-fuse.net/issues/94
BuildRequires: zfs-fuse
%endif

# For building the appliance.
Requires:      supermin >= 5.1.18

# The daemon dependencies are not included automatically, because it
# is buried inside the appliance, so list them here.
Requires:      hivex%{?_isa} >= 1.3.10
Requires: pcre
#Requires: libselinux-utils
Requires: yajl

# For core inspection API.
Requires:      db5-utils

# For core mount-local (FUSE) API.
Requires:      fuse

# For core disk-create API.
Requires:      qemu-img

# For libvirt backend.
%ifarch %{ix86} x86_64 %{arm} aarch64
Requires:      qemu-kvm
%endif

%if %{runtests}
BuildRequires: ruby-test-unit
%endif

%description
Libguestfs is a library for accessing and modifying virtual machine
disk images.  http://libguestfs.org

It can be used to make batch configuration changes to guests, get disk
used/free statistics (virt-df), perform backups and guest clones,
change registry/UUID/hostname info, build guests from scratch
(virt-builder) and much more.

Libguestfs uses Linux kernel and qemu code, and can access any type of
guest filesystem that Linux and qemu can, including but not limited
to: ext2/3/4, btrfs, FAT and NTFS, LVM, many different disk partition
schemes, qcow, qcow2, vmdk.

Libguestfs is split into several subpackages.  The basic subpackages are:

               libguestfs  C library
         libguestfs-tools  virt-* tools, guestfish and guestmount (FUSE)
       libguestfs-tools-c  only the subset of virt tools written in C
                             (for reduced dependencies)
                 virt-dib  safe and secure diskimage-builder replacement

For enhanced features, install:

     libguestfs-forensics  adds filesystem forensics support
          libguestfs-gfs2  adds Global Filesystem (GFS2) support
       libguestfs-hfsplus  adds HFS+ (Mac filesystem) support
 libguestfs-inspect-icons  adds support for inspecting guest icons
           libguestfs-jfs  adds JFS support
         libguestfs-nilfs  adds NILFS v2 support
      libguestfs-reiserfs  adds ReiserFS support
        libguestfs-rescue  enhances virt-rescue shell with more tools
         libguestfs-rsync  rsync to/from guest filesystems
           libguestfs-ufs  adds UFS (BSD) support
           libguestfs-xfs  adds XFS support
           libguestfs-zfs  adds ZFS support

For developers:

         libguestfs-devel  C/C++ header files and library

Language bindings:

 libguestfs-gobject-devel  GObject bindings and GObject Introspection
%ifarch %{golang_arches}
           golang-guestfs  Go language bindings
%endif
              lua-guestfs  Lua bindings
   ocaml-libguestfs-devel  OCaml bindings
         perl-Sys-Guestfs  Perl bindings
           php-libguestfs  PHP bindings
       python3-libguestfs  Python 3 bindings
          ruby-libguestfs  Ruby bindings
          libguestfs-vala  Vala language bindings


%package devel
Summary:       Development tools and libraries for %{name}
Group:         System/Libraries
Requires:      %{name}%{?_isa} = %{epoch}:%{version}-%{release}
Requires:      pkgconfig

# For libguestfs-make-fixed-appliance.
Requires:      xz
Requires:      %{name}-tools-c = %{epoch}:%{version}-%{release}

%description devel
%{name}-devel contains development tools and libraries
for %{name}.


%package forensics
Summary:       Filesystem forensics support for %{name}
License:       LGPLv2+
Group:         Development/Tools
Requires:      %{name}%{?_isa} = %{epoch}:%{version}-%{release}


%description forensics
This adds filesystem forensics support to %{name}.  Install it if you
want to forensically analyze disk images using The Sleuth Kit.


%package gfs2
Summary:       GFS2 support for %{name}
License:       LGPLv2+
Requires:      %{name}%{?_isa} = %{epoch}:%{version}-%{release}

%description gfs2
This adds GFS2 support to %{name}.  Install it if you want to process
disk images containing GFS2.


%ifnarch ppc
%package hfsplus
Summary:       HFS+ support for %{name}
License:       LGPLv2+
Requires:      %{name}%{?_isa} = %{epoch}:%{version}-%{release}

%description hfsplus
This adds HFS+ support to %{name}.  Install it if you want to process
disk images containing HFS+ / Mac OS Extended filesystems.
%endif


%package jfs
Summary:       JFS support for %{name}
License:       LGPLv2+
Requires:      %{name}%{?_isa} = %{epoch}:%{version}-%{release}

%description jfs
This adds JFS support to %{name}.  Install it if you want to process
disk images containing JFS.


%package nilfs
Summary:       NILFS support for %{name}
License:       LGPLv2+
Requires:      %{name}%{?_isa} = %{epoch}:%{version}-%{release}

%description nilfs
This adds NILFS v2 support to %{name}.  Install it if you want to process
disk images containing NILFS v2.


%package reiserfs
Summary:       ReiserFS support for %{name}
License:       LGPLv2+
Requires:      %{name}%{?_isa} = %{epoch}:%{version}-%{release}

%description reiserfs
This adds ReiserFS support to %{name}.  Install it if you want to process
disk images containing ReiserFS.


%package rescue
Summary:       Additional tools for virt-rescue
License:       LGPLv2+
Requires:      %{name}-tools-c = %{epoch}:%{version}-%{release}

%description rescue
This adds additional tools to use inside the virt-rescue shell,
such as ssh, network utilities, editors and debugging utilities.


%package rsync
Summary:       rsync support for %{name}
License:       LGPLv2+
Requires:      %{name}%{?_isa} = %{epoch}:%{version}-%{release}

%description rsync
This adds rsync support to %{name}.  Install it if you want to use
rsync to upload or download files into disk images.


%package ufs
Summary:       UFS (BSD) support for %{name}
License:       LGPLv2+
Requires:      %{name}%{?_isa} = %{epoch}:%{version}-%{release}

%description ufs
This adds UFS support to %{name}.  Install it if you want to process
disk images containing UFS (BSD filesystems).


%package xfs
Summary:       XFS support for %{name}
License:       LGPLv2+
Requires:      %{name}%{?_isa} = %{epoch}:%{version}-%{release}

%description xfs
This adds XFS support to %{name}.  Install it if you want to process
disk images containing XFS.


%ifnarch %{arm} aarch64 s390 s390x riscv64
%package zfs
Summary:       ZFS support for %{name}
License:       LGPLv2+
Requires:      %{name}%{?_isa} = %{epoch}:%{version}-%{release}

%description zfs
This adds ZFS support to %{name}.  Install it if you want to process
disk images containing ZFS.
%endif


%package inspect-icons
Summary:       Additional dependencies for inspecting guest icons
License:       LGPLv2+
BuildArch:     noarch
Requires:      %{name} = %{epoch}:%{version}-%{release}

Requires:      netpbm
Requires:      icoutils


%description inspect-icons
%{name}-inspect-icons is a metapackage that pulls in additional
dependencies required by libguestfs to pull icons out of non-Linux
guests.  Install this package if you want libguestfs to be able to
inspect non-Linux guests and display icons from them.

The only reason this is a separate package is to avoid core libguestfs
having to depend on Perl.  See https://bugzilla.redhat.com/1194158


%package tools-c
Summary:       System administration tools for virtual machines
License:       GPLv2+
Requires:      %{name}%{?_isa} = %{epoch}:%{version}-%{release}

# For guestfish:
#Requires:      /usr/bin/emacs #theoretically, but too large
Requires:      hexedit
Requires:      less
Requires:      man
Requires:      vim-minimal

# For virt-builder:
Requires:      gnupg2
Requires:      xz
#Requires:     nbdkit, nbdkit-plugin-xz
Requires:      curl

# For virt-builder-repository:
Recommends:      osinfo-db

Recommends:    libguestfs-xfs

# For virt-edit and virt-customize:
Suggests:      perl


%description tools-c
This package contains miscellaneous system administrator command line
tools for virtual machines.

Note that you should install %{name}-tools (which pulls in
this package).  This package is only used directly when you want
to avoid dependencies on Perl.


%package tools
Summary:       System administration tools for virtual machines
Group:         Development/Tools
License:       GPLv2+
BuildArch:     noarch
Requires:      %{name} = %{epoch}:%{version}-%{release}
Requires:      %{name}-tools-c = %{epoch}:%{version}-%{release}


%description tools
This package contains miscellaneous system administrator command line
tools for virtual machines.

Guestfish is the Filesystem Interactive SHell, for accessing and
modifying virtual machine disk images from the command line and shell
scripts.

The guestmount command lets you mount guest filesystems on the host
using FUSE and %{name}.

Virt-alignment-scan scans virtual machines looking for partition
alignment problems.

Virt-builder is a command line tool for rapidly making disk images
of popular free operating systems.

Virt-cat is a command line tool to display the contents of a file in a
virtual machine.

Virt-copy-in and virt-copy-out are command line tools for uploading
and downloading files and directories to and from virtual machines.

Virt-customize is a command line tool for customizing virtual machine
disk images.

Virt-df is a command line tool to display free space on virtual
machine filesystems.  Unlike other tools, it doesn’t just display the
amount of space allocated to a virtual machine, but can look inside
the virtual machine to see how much space is really being used.  It is
like the df(1) command, but for virtual machines, except that it also
works for Windows virtual machines.

Virt-diff shows the differences between virtual machines.

Virt-edit is a command line tool to edit the contents of a file in a
virtual machine.

Virt-filesystems is a command line tool to display the filesystems,
partitions, block devices, LVs, VGs and PVs found in a disk image
or virtual machine.  It replaces the deprecated programs
virt-list-filesystems and virt-list-partitions with a much more
capable tool.

Virt-format is a command line tool to erase and make blank disks.

Virt-get-kernel extracts a kernel/initrd from a disk image.

Virt-inspector examines a virtual machine and tries to determine the
version of the OS, the kernel version, what drivers are installed,
whether the virtual machine is fully virtualized (FV) or
para-virtualized (PV), what applications are installed and more.

Virt-log is a command line tool to display the log files from a
virtual machine.

Virt-ls is a command line tool to list out files in a virtual machine.

Virt-make-fs is a command line tool to build a filesystem out of
a collection of files or a tarball.

Virt-rescue provides a rescue shell for making interactive,
unstructured fixes to virtual machines.

Virt-resize can resize existing virtual machine disk images.

Virt-sparsify makes virtual machine disk images sparse (thin-provisioned).

Virt-sysprep lets you reset or unconfigure virtual machines in
preparation for cloning them.

Virt-tail follows (tails) a log file within a guest, like 'tail -f'.

Virt-tar-in and virt-tar-out are archive, backup and upload tools
for virtual machines.  These replace the deprecated program virt-tar.

Virt-win-reg lets you look at and modify the Windows Registry of
Windows virtual machines.


%package -n virt-dib
Summary:       Safe and secure diskimage-builder replacement
License:       GPLv2+

Requires:      %{name}%{?_isa} = %{epoch}:%{version}-%{release}


%description -n virt-dib
Virt-dib is a safe and secure alternative to the OpenStack
diskimage-builder command.  It is compatible with most
diskimage-builder elements.

%package bash-completion
Summary:       Bash tab-completion scripts for %{name} tools
BuildArch:     noarch
Requires:      bash-completion >= 2.0
Requires:      %{name}-tools-c = %{epoch}:%{version}-%{release}


%description bash-completion
Install this package if you want intelligent bash tab-completion
for guestfish, guestmount and various virt-* tools.


%package -n ocaml-%{name}
Summary:       OCaml bindings for %{name}
Group:         Development/OCaml
Requires:      %{name}%{?_isa} = %{epoch}:%{version}-%{release}


%description -n ocaml-%{name}
ocaml-%{name} contains OCaml bindings for %{name}.

This is for toplevel and scripting access only.  To compile OCaml
programs which use %{name} you will also need ocaml-%{name}-devel.


%package -n ocaml-%{name}-devel
Summary:       OCaml bindings for %{name}
Group:         Development/OCaml
Requires:      ocaml-%{name}%{?_isa} = %{epoch}:%{version}-%{release}


%description -n ocaml-%{name}-devel
ocaml-%{name}-devel contains development libraries
required to use the OCaml bindings for %{name}.


%package -n perl-Sys-Guestfs
Summary:       Perl bindings for %{name} (Sys::Guestfs)
Group:         Development/Perl
Requires:      %{name}%{?_isa} = %{epoch}:%{version}-%{release}
Requires:      perl


%description -n perl-Sys-Guestfs
perl-Sys-Guestfs contains Perl bindings for %{name} (Sys::Guestfs).


%package -n python3-%{name}
Summary:       Python 3 bindings for %{name}
Requires:      %{name}%{?_isa} = %{epoch}:%{version}-%{release}
%{?python_provide:%python_provide python3-%{name}}


%description -n python3-%{name}
python3-%{name} contains Python 3 bindings for %{name}.
 

%package -n ruby-%{name}
Summary:       Ruby bindings for %{name}
Group:         Development/Ruby
Requires:      %{name}%{?_isa} = %{epoch}:%{version}-%{release}
Requires:      ruby(release)
Requires:      ruby
Provides:      ruby(guestfs) = %{version}

%description -n ruby-%{name}
ruby-%{name} contains Ruby bindings for %{name}.

%if %with php
%package -n php-%{name}
Summary:       PHP bindings for %{name}
Group:         Development/PHP
Requires:      %{name}%{?_isa} = %{epoch}:%{version}-%{release}
Requires:      php

%description -n php-%{name}
php-%{name} contains PHP bindings for %{name}.
%endif

%package -n lua-guestfs
Summary:       Lua bindings for %{name}
Group:         Development/Other
Requires:      %{name}%{?_isa} = %{epoch}:%{version}-%{release}
Requires:	lua

%description -n lua-guestfs
lua-guestfs contains Lua bindings for %{name}.


%package gobject
Summary:       GObject bindings for %{name}
Group:         Development/Other
Requires:      %{name}%{?_isa} = %{epoch}:%{version}-%{release}

%description gobject
%{name}-gobject contains GObject bindings for %{name}.

To develop software against these bindings, you need to install
%{name}-gobject-devel.


%package gobject-devel
Summary:       GObject bindings for %{name}
Group:         Development/C
Requires:      %{name}-gobject = %{epoch}:%{version}-%{release}

%description gobject-devel
%{name}-gobject contains GObject bindings for %{name}.

This package is needed if you want to write software using the
GObject bindings.  It also contains GObject Introspection information.


%package vala
Summary:       Vala for %{name}
Requires:      %{name}-devel%{?_isa} = %{epoch}:%{version}-%{release}
Requires:      vala


%description vala
%{name}-vala contains GObject bindings for %{name}.



%ifarch %{golang_arches}
%package -n golang-guestfs
Summary:       Golang bindings for %{name}
Group:         Development/Other
BuildArch:     noarch
Requires:      %{name} = %{epoch}:%{version}-%{release}
Requires:      golang
Provides:      golang(libguestfs.org) = %{epoch}:%{version}-%{release}

%description -n golang-guestfs
golang-%{name} contains Go language bindings for %{name}.
%endif


%package man-pages-ja
Summary:       Japanese (ja) man pages for %{name}
BuildArch:     noarch
Requires:      %{name} = %{epoch}:%{version}-%{release}

%description man-pages-ja
%{name}-man-pages-ja contains Japanese (ja) man pages
for %{name}.


%package man-pages-uk
Summary:       Ukrainian (uk) man pages for %{name}
BuildArch:     noarch
Requires:      %{name} = %{epoch}:%{version}-%{release}

%description man-pages-uk
%{name}-man-pages-uk contains Ukrainian (uk) man pages
for %{name}.


%prep
%if 0%{verify_tarball_signature}
%{gpgverify} --keyring='%{SOURCE7}' --signature='%{SOURCE1}' --data='%{SOURCE0}'
%endif
%setup -q
%autopatch -p1

%if 0%{patches_touch_autotools}
sed -i -e '/AM_GNU_GETTEXT/d' m4/guestfs-libraries.m4
sed -i -e 's/\(AM_INIT_AUTOMAKE.*\)/\1\nAM_GNU_GETTEXT([external])\nAM_GNU_GETTEXT_REQUIRE_VERSION([0.21])/' configure.ac
autoreconf -fi
%endif

# Replace developer-centric README that ships with libguestfs, with
# our replacement file.
mv README README.orig
sed 's/@VERSION@/%{version}/g' < %{SOURCE4} > README
sed -i 's!Fedora!Mageia!' README


%build
%{configure} \
  PYTHON=%{__python3} \
  --with-default-backend=libvirt \
  --with-extra="mageia=%{mageia},release=%{release},libvirt" \
%ifnarch %{golang_arches}
  --disable-golang \
%endif 
%ifarch %{arm}
  --disable-haskell \
%endif
  --without-java \
  --disable-erlang \
  $extra

# Building index-parse.c by hand works around a race condition in the
# autotools cruft, where two or more copies of yacc race with each
# other, resulting in a corrupted file.
#
# 'INSTALLDIRS' ensures that Perl and Ruby libs are installed in the
# vendor dir not the site dir.
make -j1 -C builder index-parse.c
make V=1 INSTALLDIRS=vendor %{?_smp_mflags}


%check
%if %{runtests}
%ifarch %{test_arches}
export LIBGUESTFS_DEBUG=1
export LIBGUESTFS_TRACE=1
export LIBVIRT_DEBUG=1

if ! make quickcheck QUICKCHECK_TEST_TOOL_ARGS="-t 1200"; then
    cat $HOME/.cache/libvirt/qemu/log/*
    exit 1
fi
%endif
%endif


%install
# This file is creeping over 1 MB uncompressed, and since it is
# included in the -devel subpackage, compress it to reduce
# installation size.
gzip -9 ChangeLog

# 'INSTALLDIRS' ensures that Perl and Ruby libs are installed in the
# vendor dir not the site dir.
make DESTDIR=$RPM_BUILD_ROOT INSTALLDIRS=vendor install

# Delete static libraries.
rm $( find $RPM_BUILD_ROOT -name '*.a' | grep -v /ocaml/ )

# Delete libtool files.
find $RPM_BUILD_ROOT -name '*.la' -delete

# Delete some bogus Perl files.
find $RPM_BUILD_ROOT -name perllocal.pod -delete
find $RPM_BUILD_ROOT -name .packlist -delete
find $RPM_BUILD_ROOT -name '*.bs' -delete
find $RPM_BUILD_ROOT -name 'bindtests.pl' -delete

# Remove obsolete binaries (RHBZ#1213298).
rm -f $RPM_BUILD_ROOT%{_bindir}/virt-list-filesystems
rm -f $RPM_BUILD_ROOT%{_bindir}/virt-list-partitions
rm -f $RPM_BUILD_ROOT%{_bindir}/virt-tar
rm -f $RPM_BUILD_ROOT%{_mandir}/man1/virt-list-filesystems.1*
rm -f $RPM_BUILD_ROOT%{_mandir}/man1/virt-list-partitions.1*
rm -f $RPM_BUILD_ROOT%{_mandir}/man1/virt-tar.1*

# golang: Ignore what libguestfs upstream installs, and just copy the
# source files to %%{_datadir}/gocode/src.
%ifarch %{golang_arches}
rm -r $RPM_BUILD_ROOT/usr/lib/golang
mkdir -p $RPM_BUILD_ROOT%{_datadir}/gocode/src
cp -a golang/src/libguestfs.org $RPM_BUILD_ROOT%{_datadir}/gocode/src
%endif

# Move installed documentation back to the source directory so
# we can install it using a %%doc rule.
mv $RPM_BUILD_ROOT%{_docdir}/libguestfs installed-docs
gzip --best installed-docs/*.xml

# Split up the monolithic packages file in the supermin appliance so
# we can install dependencies in subpackages.
pushd $RPM_BUILD_ROOT%{_libdir}/guestfs/supermin.d

function move_to
{
    if ! grep -Esq "^$1$" packages; then
        echo "move_to $1: package name not found in packages file"
        exit 1
    fi
    grep -Ev "^$1$" < packages > packages-t
    mv packages-t packages
    echo "$1" >> "$2"
}
move_to curl            zz-packages-dib
move_to debootstrap     zz-packages-dib
move_to kpartx          zz-packages-dib
move_to qemu-img        zz-packages-dib
move_to which           zz-packages-dib
move_to sleuthkit       zz-packages-forensics
move_to gfs2-utils      zz-packages-gfs2
move_to hfsplus-tools   zz-packages-hfsplus
move_to jfsutils        zz-packages-jfs
move_to nilfs-utils     zz-packages-nilfs
move_to reiserfsprogs   zz-packages-reiserfs
move_to iputils         zz-packages-rescue
move_to lsof            zz-packages-rescue
move_to openssh-clients zz-packages-rescue
move_to pciutils        zz-packages-rescue
move_to strace          zz-packages-rescue
move_to vim-minimal     zz-packages-rescue
move_to rsync           zz-packages-rsync
move_to xfsprogs        zz-packages-xfs
%ifnarch %{arm} aarch64 s390 s390x riscv64
#move_to zfs-fuse        zz-packages-zfs
%endif
popd

# Guestfish colour prompts.
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/profile.d
install -m 0644 %{SOURCE5} $RPM_BUILD_ROOT%{_sysconfdir}/profile.d

# Remove the .gitignore file from ocaml/html which will be copied to docdir.
rm ocaml/html/.gitignore


# Find locale files.
%find_lang %{name}

%files -f %{name}.lang
%doc COPYING README
%{_bindir}/libguestfs-test-tool
%{_libdir}/guestfs/
%exclude %{_libdir}/guestfs/supermin.d/zz-packages-*
%{_libdir}/libguestfs.so.*
%{_mandir}/man1/guestfs-faq.1*
%{_mandir}/man1/guestfs-performance.1*
%{_mandir}/man1/guestfs-recipes.1*
%{_mandir}/man1/guestfs-release-notes-1*.1*
%{_mandir}/man1/guestfs-release-notes-historical.1*
%{_mandir}/man1/guestfs-security.1*
%{_mandir}/man1/libguestfs-test-tool.1*


%files devel
%doc AUTHORS BUGS ChangeLog.gz HACKING TODO README
%doc examples/*.c
%doc installed-docs/*
%{_libdir}/libguestfs.so
%{_sbindir}/libguestfs-make-fixed-appliance
%{_mandir}/man1/guestfs-building.1*
%{_mandir}/man1/guestfs-hacking.1*
%{_mandir}/man1/guestfs-internals.1*
%{_mandir}/man1/guestfs-testing.1*
%{_mandir}/man1/libguestfs-make-fixed-appliance.1*
%{_mandir}/man3/guestfs.3*
%{_mandir}/man3/guestfs-examples.3*
%{_mandir}/man3/libguestfs.3*
%{_includedir}/guestfs.h
%{_libdir}/pkgconfig/libguestfs.pc

%files forensics
%{_libdir}/guestfs/supermin.d/zz-packages-forensics

%files gfs2
%{_libdir}/guestfs/supermin.d/zz-packages-gfs2

%ifnarch ppc
%files hfsplus
%{_libdir}/guestfs/supermin.d/zz-packages-hfsplus
%endif

%files jfs
%{_libdir}/guestfs/supermin.d/zz-packages-jfs

%files nilfs
%{_libdir}/guestfs/supermin.d/zz-packages-nilfs

%files reiserfs
%{_libdir}/guestfs/supermin.d/zz-packages-reiserfs

%files rsync
%{_libdir}/guestfs/supermin.d/zz-packages-rsync

%files rescue
%{_libdir}/guestfs/supermin.d/zz-packages-rescue

%files ufs
#{_libdir}/guestfs/supermin.d/zz-packages-ufs

%files xfs
%{_libdir}/guestfs/supermin.d/zz-packages-xfs

%ifnarch %{arm} aarch64 s390 s390x riscv64
%files zfs
#{_libdir}/guestfs/supermin.d/zz-packages-zfs
%endif


%files inspect-icons
# no files


%files tools-c
%doc README
%config(noreplace) %{_sysconfdir}/libguestfs-tools.conf
%{_sysconfdir}/virt-builder
%dir %{_sysconfdir}/xdg/virt-builder
%dir %{_sysconfdir}/xdg/virt-builder/repos.d
%config %{_sysconfdir}/xdg/virt-builder/repos.d/*
%config %{_sysconfdir}/profile.d/guestfish.sh
%{_mandir}/man5/libguestfs-tools.conf.5*
%{_bindir}/guestfish
%{_mandir}/man1/guestfish.1*
%{_bindir}/guestmount
%{_mandir}/man1/guestmount.1*
%{_bindir}/guestunmount
%{_mandir}/man1/guestunmount.1*
%{_bindir}/virt-alignment-scan
%{_mandir}/man1/virt-alignment-scan.1*
%{_bindir}/virt-builder
%{_mandir}/man1/virt-builder.1*
%{_bindir}/virt-builder-repository
%{_mandir}/man1/virt-builder-repository.1*
%{_bindir}/virt-cat
%{_mandir}/man1/virt-cat.1*
%{_bindir}/virt-copy-in
%{_mandir}/man1/virt-copy-in.1*
%{_bindir}/virt-copy-out
%{_mandir}/man1/virt-copy-out.1*
%{_bindir}/virt-customize
%{_mandir}/man1/virt-customize.1*
%{_bindir}/virt-df
%{_mandir}/man1/virt-df.1*
%{_bindir}/virt-diff
%{_mandir}/man1/virt-diff.1*
%{_bindir}/virt-edit
%{_mandir}/man1/virt-edit.1*
%{_bindir}/virt-filesystems
%{_mandir}/man1/virt-filesystems.1*
%{_bindir}/virt-format
%{_mandir}/man1/virt-format.1*
%{_bindir}/virt-get-kernel
%{_mandir}/man1/virt-get-kernel.1*
%{_bindir}/virt-index-validate
%{_mandir}/man1/virt-index-validate.1*
%{_bindir}/virt-inspector
%{_mandir}/man1/virt-inspector.1*
%{_bindir}/virt-log
%{_mandir}/man1/virt-log.1*
%{_bindir}/virt-ls
%{_mandir}/man1/virt-ls.1*
%{_bindir}/virt-make-fs
%{_mandir}/man1/virt-make-fs.1*
%{_bindir}/virt-rescue
%{_mandir}/man1/virt-rescue.1*
%{_bindir}/virt-resize
%{_mandir}/man1/virt-resize.1*
%{_bindir}/virt-sparsify
%{_mandir}/man1/virt-sparsify.1*
%{_bindir}/virt-sysprep
%{_mandir}/man1/virt-sysprep.1*
%{_bindir}/virt-tail
%{_mandir}/man1/virt-tail.1*
%{_bindir}/virt-tar-in
%{_mandir}/man1/virt-tar-in.1*
%{_bindir}/virt-tar-out
%{_mandir}/man1/virt-tar-out.1*

%files tools
%doc README
%{_bindir}/virt-win-reg
%{_mandir}/man1/virt-win-reg.1*

%files -n virt-dib
%doc COPYING README
%{_bindir}/virt-dib
%{_mandir}/man1/virt-dib.1*
%{_libdir}/guestfs/supermin.d/zz-packages-dib

%files bash-completion
%dir %{_datadir}/bash-completion/completions
%{_datadir}/bash-completion/completions/guestfish
%{_datadir}/bash-completion/completions/guestmount
%{_datadir}/bash-completion/completions/guestunmount
%{_datadir}/bash-completion/completions/libguestfs-test-tool
%{_datadir}/bash-completion/completions/virt-*

%files -n ocaml-%{name}
%{_libdir}/ocaml/guestfs
%exclude %{_libdir}/ocaml/guestfs/*.a
%exclude %{_libdir}/ocaml/guestfs/*.cmxa
%exclude %{_libdir}/ocaml/guestfs/*.cmx
%exclude %{_libdir}/ocaml/guestfs/*.mli
%{_libdir}/ocaml/stublibs/dllmlguestfs.so
%{_libdir}/ocaml/stublibs/dllmlguestfs.so.owner

%files -n ocaml-%{name}-devel
%doc ocaml/examples/*.ml ocaml/html
%{_libdir}/ocaml/guestfs/*.a
%{_libdir}/ocaml/guestfs/*.cmxa
%{_libdir}/ocaml/guestfs/*.cmx
%{_libdir}/ocaml/guestfs/*.mli
%{_mandir}/man3/guestfs-ocaml.3*

%files -n perl-Sys-Guestfs
%doc perl/examples/*.pl
%{perl_vendorarch}/*
%{_mandir}/man3/Sys::Guestfs.3pm*
%{_mandir}/man3/guestfs-perl.3*

%files -n python3-%{name}
%doc python/examples/*.py
%{python3_sitearch}/libguestfsmod*.so
%{python3_sitearch}/guestfs.py
%{python3_sitearch}/__pycache__/guestfs*.py*
%{_mandir}/man3/guestfs-python.3*


%files -n ruby-%{name}
%doc ruby/examples/*.rb
%doc ruby/doc/site/*
%{ruby_vendorlibdir}/guestfs.rb
%{ruby_vendorarchdir}/_guestfs.so
%{_mandir}/man3/guestfs-ruby.3*

%if %with php
%files -n php-%{name}
%doc php/README-PHP
%dir %{_sysconfdir}/php.d
%{_sysconfdir}/php.d/guestfs_php.ini
%{_libdir}/php/extensions/guestfs_php.so
%endif

%files -n lua-guestfs
%doc lua/examples/*.lua
%doc lua/examples/LICENSE
%{_libdir}/lua/*/guestfs.so
%{_mandir}/man3/guestfs-lua.3*

%files gobject
%{_libdir}/libguestfs-gobject-1.0.so.0*
%{_libdir}/girepository-1.0/Guestfs-1.0.typelib

%files gobject-devel
%{_libdir}/libguestfs-gobject-1.0.so
%{_includedir}/guestfs-gobject.h
%dir %{_includedir}/guestfs-gobject
%{_includedir}/guestfs-gobject/*.h
%{_datadir}/gir-1.0/Guestfs-1.0.gir
%{_libdir}/pkgconfig/libguestfs-gobject-1.0.pc
%{_mandir}/man3/guestfs-gobject.3*

%files vala
%{_datadir}/vala/vapi/libguestfs-gobject-1.0.deps
%{_datadir}/vala/vapi/libguestfs-gobject-1.0.vapi


%ifarch %{golang_arches}
%files -n golang-guestfs
%doc golang/examples/*.go
%doc golang/examples/LICENSE
%{_datadir}/gocode/src/libguestfs.org
%{_mandir}/man3/guestfs-golang.3*
%endif

%files man-pages-ja
%lang(ja) %{_mandir}/ja/man1/*.1*
%lang(ja) %{_mandir}/ja/man3/*.3*
%lang(ja) %{_mandir}/ja/man5/*.5*


%files man-pages-uk
%lang(uk) %{_mandir}/uk/man1/*.1*
%lang(uk) %{_mandir}/uk/man3/*.3*
%lang(uk) %{_mandir}/uk/man5/*.5*


%changelog
* Sun Jan 31 2021 neoclust <neoclust> 1:1.44.0-2.mga8
+ Revision: 1674271
- Fix buildRequires

* Thu Jan 07 2021 tv <tv> 1:1.44.0-1.mga8
+ Revision: 1669441
- New upstream stable version 1.44.0.
- Drop explicit deps on perl(Sys::Virt) and perl(Win::Hivex)

* Thu Dec 03 2020 tv <tv> 1:1.43.3-1.mga8
+ Revision: 1652073
- New upstream version 1.43.3.
- Drop merged patches

* Thu Dec 03 2020 tv <tv> 1:1.42.0-11.mga8
+ Revision: 1652068
- no need to BR gtk3-devel now that virt-p2v has been spit out
- BR rpcgen

* Tue Nov 24 2020 tv <tv> 1:1.42.0-10.mga8
+ Revision: 1648862
- include rpm in the appliance in order to "fix":
  "supermin: ext2fs_namei: parent directory not found: /var/lib/rpm: File not found by ext2_lookup"
  as a side note, mga#26089 is fixed

* Mon Nov 23 2020 tv <tv> 1:1.42.0-9.mga8
+ Revision: 1648817
- include exfatprogs in appliance
- include kernel-desktop in appliance
- restore %%atches_touch_autotools

* Mon Nov 23 2020 wally <wally> 1:1.42.0-7.mga8
+ Revision: 1648750
- fix build with autoconf 2.69d
+ tv <tv>
- Enable NTFS-3g system compression.

* Wed Aug 19 2020 joequant <joequant> 1:1.42.0-6.mga8
+ Revision: 1615571
- bump

* Sat Jul 18 2020 tv <tv> 1:1.42.0-5.mga8
+ Revision: 1607108
- rebuild for perl-5.32 (binary package w/o a dep on libperl.so
- rebuild for perl-5.32

* Wed Jun 10 2020 joequant <joequant> 1:1.42.0-3.mga8
+ Revision: 1591594
- rebuild
+ tv <tv>
- Fix path to libguestfs appliance
- BR curl, adjust genisoimage BR for easier comp

* Thu Mar 12 2020 tv <tv> 1:1.42.0-2.mga8
+ Revision: 1555856
- Enable NTFS-3g system compression

* Wed Mar 11 2020 tv <tv> 1:1.42.0-1.mga8
+ Revision: 1555536
- Drop erlang bindings.
- virt-v2v is now in a separate project.
- add the ability to verify sources
- drop mga5->mga6 obsoletes tags
- no need to recompile twice for py2/3 anymore
- New upstream stable version 1.42.0.
- Drop the benchmarking subpackage: moved to a new package upstream.
- Enable Vala bindings.
- drop patches on no more existing files

* Fri Feb 28 2020 umeabot <umeabot> 1:1.40.2-5.mga8
+ Revision: 1551739
- Rebuild for ocaml 4.10.0 final

* Wed Feb 19 2020 umeabot <umeabot> 1:1.40.2-4.mga8
+ Revision: 1543905
- Mageia 8 Mass Rebuild

* Thu Jan 23 2020 tv <tv> 1:1.40.2-3.mga8
+ Revision: 1482306
- rebuild for ocaml-4.10

* Sat Jan 04 2020 luigiwalser <luigiwalser> 1:1.40.2-2.mga8
+ Revision: 1475979
- rebuild for readline

* Sun Oct 06 2019 tv <tv> 1:1.40.2-1.mga8
+ Revision: 1449965
- drop python2 bindings
- fix detecting db_dump
- adjust BRs
- fix enabling fuse support (incompatible with fuse3)
- disable zfs subpkg for now
- BR kpartx
- BR debootstrap
- BR magic-devel
- new release

* Thu Apr 25 2019 joequant <joequant> 1:1.38.6-4.mga7
+ Revision: 1395250
- revert because of version freeze
- update to 1.40.2

* Thu Apr 25 2019 joequant <joequant> 1:1.38.6-3.mga7
+ Revision: 1395221
- rebuild

* Tue Jan 08 2019 tv <tv> 1:1.38.6-2.mga7
+ Revision: 1351702
- rebuild with python 3.7

* Tue Oct 23 2018 tv <tv> 1:1.38.6-1.mga7
+ Revision: 1324326
- new release

* Sun Sep 23 2018 umeabot <umeabot> 1:1.38.0-4.mga7
+ Revision: 1298897
- Mageia 7 Mass Rebuild

* Thu Aug 09 2018 pterjan <pterjan> 1:1.38.0-3.mga7
+ Revision: 1250546
- Rebuild for perl 5.28

* Fri Apr 06 2018 kekepower <kekepower> 1:1.38.0-2.mga7
+ Revision: 1215611
- Rebuild for new libconfig

* Wed Feb 21 2018 tv <tv> 1:1.38.0-1.mga7
+ Revision: 1203971
- new release

* Wed Feb 07 2018 tv <tv> 1:1.37.37-1.mga7
+ Revision: 1199574
- new release

* Tue Jan 23 2018 tv <tv> 1:1.37.35-1.mga7
+ Revision: 1196562
- new release

* Mon Jan 01 2018 pterjan <pterjan> 1:1.37.34-2.mga7
+ Revision: 1188460
- Rebuild for Ruby 2.5

* Wed Dec 06 2017 tv <tv> 1:1.37.34-1.mga7
+ Revision: 1181579
- disable php support for now
- replace developer-centric README with a better one
- use %%autopatch
- fix locking on NBD drives
- new release

* Wed Nov 01 2017 tv <tv> 1:1.37.31-1.mga7
+ Revision: 1175305
- new release

* Sat Oct 14 2017 tv <tv> 1:1.37.29-1.mga7
+ Revision: 1171821
- disable ufs in filelist
- new release
- Add libguestfs-ufs (BSD) subpackage

* Wed Sep 13 2017 tv <tv> 1:1.37.22-4.mga7
+ Revision: 1153609
- fix deps

* Wed Sep 13 2017 tv <tv> 1:1.37.22-3.mga7
+ Revision: 1153536
- add one more linking fix
- new release
- BR ocaml-hivex-devel
- new release
- fix missing lib
- Fix missing dependencies in the appliance
- benchmarking: Don't install libtool wrapper scripts
- rediff patches
- new release
+ pterjan <pterjan>
- Rebuild for new Ruby
- Rebuild for python 3.6

* Wed Feb 08 2017 pterjan <pterjan> 1:1.34.3-2.mga6
+ Revision: 1085189
- Backport a second upstream patch for gperf 3.1
- Add upstream patch for gperf 3.1 api change

* Thu Oct 27 2016 shlomif <shlomif> 1:1.34.3-1.mga6
+ Revision: 1063778
- New version 1.34.3.
- Upgrade to 1.34.2 (next stable) - fixes MGA#19581 .

* Tue Sep 27 2016 luigiwalser <luigiwalser> 1:1.33.36-5.mga6
+ Revision: 1057093
- rebuild without ghc

* Sun Sep 25 2016 pterjan <pterjan> 1:1.33.36-4.mga6
+ Revision: 1056216
- Rebuild for fix in ocaml

* Thu Sep 15 2016 tv <tv> 1:1.33.36-3.mga6
+ Revision: 1053020
- do not link with SELinux

* Mon Jun 27 2016 tv <tv> 1:1.33.36-2.mga6
+ Revision: 1037915
- requires libldm

* Sat Jun 18 2016 tv <tv> 1:1.33.36-1.mga6
+ Revision: 1022059
- rename gobject subpkg
- split devel & doc supkgs from it
- adjust ruby provides/requires
- new release
- build virt-p2v with gtk3 instead of gtk2
- add libguestfs-benchmarking subpackage
- disable testsuite on ia32
- make tools subpkg noarch
- recommends libguestfs-xfs
- drop redundant erlang BRs
- exclude armv5 as it doesn't support qemu-kvm

* Fri Jun 17 2016 tv <tv> 1:1.33.23-8.mga6
+ Revision: 1022024
- drop BR on grub
- fix requires

* Fri Jun 17 2016 tv <tv> 1:1.33.23-7.mga6
+ Revision: 1021974
- fix inverted test

* Fri Jun 17 2016 tv <tv> 1:1.33.23-6.mga6
+ Revision: 1021901
- disable haskell bindings on ARM until ghc is availlable

* Thu Jun 16 2016 tv <tv> 1:1.33.23-4.mga6
+ Revision: 1021714
- move some man-pages in devel subpkg
- revert to gtk2, gtk3 needs a newer version
- move pciutils to libguestfs-rescue subpackage
- build virt-p2v with gtk3 instead of gtk2
- BR zfs-fuse

* Wed Apr 27 2016 tv <tv> 1:1.33.23-3.mga6
+ Revision: 1006801
+ rebuild (emptylog)

* Wed Apr 27 2016 tv <tv> 1:1.33.23-2.mga6
+ Revision: 1006796
- rename golang package
- disable golang support
- BR sleuthkit
- ocaml-xml-light is no longer required.
- BR ocaml-compiler for ocamldoc
- libguestfs-test-tool does not require genisoimage
- add some requires
- BR syslinux
- BR some ruby packages
- BR db5-utils
- BR libldm-devel
- add BR on some ocaml pkgs
- BR perl-devel
- remove external dependency generator -- use supermin RPM deps instead
- revert, supermin is now mandatory
- disable supermin support
- drop BR on erlang-devel
- adjust filelist
- add some supermin sub packages
- add missing requires to devel pkg
- add python3 bindings
- rename python-libguestfs as python2-libguestfs
- rename perl-libguestfs as perl-Sys-Guestfs
- merge guestfish & libguestfs-mount packages into libguestfs-tools
- introduce libguestfs-forensics
- add default perl provides filter
- BR cdrkit-genisoimage
- BR gtk2-devel xz-devel libacl-devel libcap-devel yajl-devel & systemd-devel
- BR supermin-devel instead of supermin
- BR qemu-img instead of qemu
- new release
- requires qemu-kvm instead of qemu

* Fri Mar 18 2016 daviddavid <daviddavid> 1:1.33.14-1.mga6
+ Revision: 992786
- re-enable PHP support
- adjust doc files list and files list
- rebuild for new ocaml
+ tv <tv>
- disable underlinking
- fix source URL
- adjust file list + create devel pkg

* Fri Nov 20 2015 tv <tv> 1:1.31.20-1.mga6
+ Revision: 904585
- adjust file list + create devel pkg
- adjust file list
- further sync BRs with FC
- ncurses-devel BR seems useless
- BR flex+bison
- temporary disable PHP support
- BR perl(Module::Build)
- new release

* Sat Jun 27 2015 tv <tv> 1:1.27.39-12.mga6
+ Revision: 846062
- rebuild for soname-ifed perl

* Tue Jun 23 2015 tv <tv> 1:1.27.39-11.mga6
+ Revision: 841129
- rebuild for perl-5.22

* Wed Oct 15 2014 umeabot <umeabot> 1:1.27.39-10.mga5
+ Revision: 746635
- Second Mageia 5 Mass Rebuild

* Mon Oct 06 2014 joequant <joequant> 1:1.27.39-9.mga5
+ Revision: 737050
- add missing requires

* Sat Sep 27 2014 tv <tv> 1:1.27.39-8.mga5
+ Revision: 726072
- remove file deps added by joequant 2 weeks ago

* Fri Sep 26 2014 tv <tv> 1:1.27.39-7.mga5
+ Revision: 725102
- rebuild for bogus file deps

* Mon Sep 22 2014 tv <tv> 1:1.27.39-6.mga5
+ Revision: 718658
- rebuild to get rid of /bin/bash deps
+ umeabot <umeabot>
- Mageia 5 Mass Rebuild
+ joequant <joequant>
- split up packages like fedora

* Tue Sep 09 2014 joequant <joequant> 1:1.27.39-3.mga5
+ Revision: 673831
- put in hivex in build

* Mon Sep 08 2014 joequant <joequant> 1:1.27.39-2.mga5
+ Revision: 673764
- turn off default
- parallel compile except for v2v
- start up tests - add comment

* Sun Sep 07 2014 tv <tv> 1:1.27.39-1.mga5
+ Revision: 673330
- fix build + adjust file list
- rediff patch 2
- new release

* Thu Sep 04 2014 joequant <joequant> 1:1.27.33-3.mga5
+ Revision: 671748
- rebuild against new systemd so that supermin will pick up libraries

* Sat Aug 30 2014 joequant <joequant> 1:1.27.33-2.mga5
+ Revision: 669375
- single thread build
- increment version
- add ocaml compiler libs to buildrequires
- update

* Fri Jun 06 2014 tv <tv> 1:1.27.14-3.mga5
+ Revision: 633888
- BR yajl

* Fri Jun 06 2014 tv <tv> 1:1.27.14-2.mga5
+ Revision: 633884
- fix bogus package name in upstreamed patch
  should fix the following error:
  "guestfsd: error while loading shared libraries: libyajl.so.2: cannot open
  shared object file: No such file or directory"

* Thu Jun 05 2014 tv <tv> 1:1.27.14-1.mga5
+ Revision: 633581
- drop merged patch
- new release

* Thu May 29 2014 joequant <joequant> 1:1.27.13-1.mga5
+ Revision: 627433
- upgrade to 1.27.13

* Thu May 29 2014 joequant <joequant> 1:1.26.2-1.mga5
+ Revision: 627391
- add requirements for perl tools
- more debug lines
- add listdrivers for test
- sync files
- update to 1.26.2

* Fri Apr 25 2014 blino <blino> 1:1.24.5-3.mga5
+ Revision: 617711
- remove apparently useless dependency to iurt

* Mon Feb 24 2014 tmb <tmb> 1:1.24.5-2.mga5
+ Revision: 596623
- guestfish: change file requires to package requires (mga#12869)

* Fri Jan 24 2014 oden <oden> 1:1.24.5-1.mga4
+ Revision: 567708
- 1.24.5
- rediff patches
+ pterjan <pterjan>
- Rebuild for new PHP

* Mon Jan 06 2014 dmorgan <dmorgan> 1:1.24.0-8.mga4
+ Revision: 565001
- Rebuild to please autobuild

* Thu Nov 28 2013 joequant <joequant> 1:1.24.0-7.mga4
+ Revision: 553811
- remove custom requires

* Thu Nov 28 2013 joequant <joequant> 1:1.24.0-6.mga4
+ Revision: 553804
- package libraries with readlink

* Mon Nov 25 2013 joequant <joequant> 1:1.24.0-5.mga4
+ Revision: 553073
- don't use custom requires for libguestfs

* Tue Nov 19 2013 colin <colin> 1:1.24.0-4.mga4
+ Revision: 551956
- Rebuild for new libdri

* Tue Nov 12 2013 tv <tv> 1:1.24.0-3.mga4
+ Revision: 550710
- requires supermin-helper in order to be able to mount disk images

* Wed Oct 23 2013 joequant <joequant> 1:1.24.0-2.mga4
+ Revision: 546691
- fix mandir error in build
- upgrade to 1.24.0 - fix 11497 - CVE 2013-4419
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild

* Mon Oct 14 2013 joequant <joequant> 1:1.23.31-1.mga4
+ Revision: 497105
- update to 1.23.31

* Thu Oct 10 2013 joequant <joequant> 1:1.23.28-1.mga4
+ Revision: 494749
- upgrade to 1.23.28

* Wed Oct 09 2013 joequant <joequant> 1:1.23.27-1.mga4
+ Revision: 494027
- add source package
- upgrade to 1.22.27 and golang

* Tue Oct 08 2013 colin <colin> 1:1.23.20-4.mga4
+ Revision: 493619
- Rebuild for new ncurses based termcap

* Thu Sep 26 2013 fwang <fwang> 1:1.23.20-3.mga4
+ Revision: 486526
- update file list
- rebuild for ruby 2.0

* Sun Sep 08 2013 joequant <joequant> 1:1.23.20-2.mga4
+ Revision: 476207
- add requires

* Mon Sep 02 2013 joequant <joequant> 1:1.23.20-1.mga4
+ Revision: 474327
- upgrade to 1.23.20

* Sat Aug 31 2013 fwang <fwang> 1:1.23.13-8.mga4
+ Revision: 473668
- rebuild for new sasl

* Sat Aug 24 2013 fwang <fwang> 1:1.23.13-7.mga4
+ Revision: 470446
- rebuild for new mesagl

* Mon Aug 19 2013 joequant <joequant> 1:1.23.13-6.mga4
+ Revision: 467602
- reduce description length

* Sat Aug 17 2013 joequant <joequant> 1:1.23.13-5.mga4
+ Revision: 467320
- bump to new supermin

* Sat Aug 17 2013 joequant <joequant> 1:1.23.13-4.mga4
+ Revision: 467154
- fix libintl dep

* Sat Aug 17 2013 fwang <fwang> 1:1.23.13-3.mga4
+ Revision: 467092
- drop invalid ruby req

* Fri Aug 16 2013 joequant <joequant> 1:1.23.13-2.mga4
+ Revision: 466909
- add build requires
- libguestfs fixes

* Wed Aug 14 2013 joequant <joequant> 1:1.23.13-1.mga4
+ Revision: 466430
- add buildrequires as pkgconfig
- add more build requires
- fix build requires
- fix libguestfs group
- add sources for libguestfs
- upgrade and update libguestfs
- revert deletion
+ saispo <saispo>
- imported package libguestfs

